/*
 Copyright 2016-2023, InvenSense, Inc.  All rights reserved.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.

 */
#include "ioport.h"
#include "board_sync_meas_hal.h"
#include "board_sync_meas.h"

uint8_t board_sync_meas_hal_init(void)
{
	pio_enable_interrupt(PIN_EXT_INTERRUPT_PIO, PIN_EXT_SyncMeasINT_MASK);
	ioport_set_pin_mode(PIN_SYNC_MEAS, IOPORT_MODE_PULLUP);
	ioport_set_pin_dir(PIN_SYNC_MEAS, IOPORT_DIR_INPUT);
	ioport_set_pin_level(PIN_SYNC_MEAS, 0);

	return 0;
}

void board_sync_meas_ready_hal_isr_callback(void)
{
	/* When the "Ready" pin goes high, start the next measurement and enable the algo */
	if (ioport_get_pin_level(PIN_SYNC_MEAS) == IOPORT_PIN_LEVEL_HIGH)
		board_sync_meas_meas_start();
	else
		/* When the "Ready" pin goes low, stop the measurement and disable the algo */
		board_sync_meas_stop_and_wait(false);
}

uint8_t board_sync_meas_hal_ready(bool ready)
{
	if(ready)
		ioport_set_pin_dir(PIN_SYNC_MEAS, IOPORT_DIR_INPUT);
	else
		ioport_set_pin_dir(PIN_SYNC_MEAS, IOPORT_DIR_OUTPUT);

	return 0;
}