/*
 Copyright 2016-2023, InvenSense, Inc.  All rights reserved.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.

 */
#include <asf.h>
#include <ioport.h>
#include "stdio_serial.h"
#include "console_hal.h"

#define IOPORT_SET_PORT_PERIPHERAL_MODE(port, masks, mode) \
	do {\
		ioport_set_port_mode(port, masks, mode);\
		ioport_disable_port(port, masks);\
	} while (0)

#define IOPORT_SET_PIN_PERIPHERAL_MODE(pin, mode) \
	do {\
		ioport_set_pin_mode(pin, mode);\
		ioport_disable_pin(pin);\
	} while (0)

/* Use the EDBG console for debug */
void console_hal_init(void)
{

	/* USART7 / EDBG */
	IOPORT_SET_PORT_PERIPHERAL_MODE(PINS_USART7_PORT, PINS_USART7, PINS_USART7_FLAGS);
	IOPORT_SET_PIN_PERIPHERAL_MODE(IOPORT_CREATE_PIN(PIOA, 27), PINS_USART7_FLAGS);
	IOPORT_SET_PIN_PERIPHERAL_MODE(IOPORT_CREATE_PIN(PIOA, 28), PINS_USART7_FLAGS);

	const usart_serial_options_t uart_serial_options = {
		.baudrate = CONF_UART_BAUDRATE,
		.charlength = CONF_UART_CHAR_LENGTH,
		.paritytype = CONF_UART_PARITY,
		.stopbits = CONF_UART_STOP_BITS,
	};

	/* Configure console UART. */
	sysclk_enable_peripheral_clock(CONF_UART_ID);
	usart_serial_init(CONF_UART, (usart_serial_options_t *)&uart_serial_options);

	stdio_serial_init(CONF_UART, &uart_serial_options);

	usart_enable_rx(CONF_UART);
	usart_enable_tx(CONF_UART);

	/* no IRQ on console UART */

}