/*
 Copyright 2016-2023, InvenSense, Inc.  All rights reserved.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.

 */
#include <stdbool.h>
#include <asf.h>
#include "time_hal.h"
#include "delay.h"
#include "tc.h"
#include "chirp_smartsonic.h"

int8_t time_hal_init(void)
{
	/* TC0 init'd in chbsp_chirp_samg55.c / timers_init() */
	return 0;
}

uint64_t time_hal_get_in_us(void)
{
	static uint64_t lsepoch_overflow_counter_in_tick = 0;

	cpu_irq_enter_critical();
	/* Check if a counter overflow occurs since last call and ensure no ovf occurs during the read */
	if (TC0->TC_CHANNEL[TC_CHANNEL_LSEPOCH].TC_SR & TC_SR_COVFS)
		lsepoch_overflow_counter_in_tick += 65536;

	uint16_t timer_counter = TC0->TC_CHANNEL[TC_CHANNEL_LSEPOCH].TC_CV;

	if (TC0->TC_CHANNEL[TC_CHANNEL_LSEPOCH].TC_SR & TC_SR_COVFS) {
		lsepoch_overflow_counter_in_tick += 65536;
		/* Overflow occurred during the reading */
		timer_counter = 0;
	}


	/* Convert to us */
	uint64_t curr_time = ((lsepoch_overflow_counter_in_tick + timer_counter) * 1000000)
		/ ULTRASOUND_TIMER_FREQUENCY;
	cpu_irq_leave_critical();

	return (curr_time);
}

void time_hal_delay_us(uint32_t us)
{
	delay_us(us);
}
