/*
 Copyright 2016-2023, InvenSense, Inc.  All rights reserved.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.

 */
/** \file chirp_smartsonic.h */
#ifndef CHIRP_SMARTSONIC_H
#define CHIRP_SMARTSONIC_H

#include <stdbool.h>

#include <invn/soniclib/soniclib.h>
#include "chirp_board_config.h"
#include "app_config.h"

/* Standard symbols used in board support package - use values from config header */
#define CHBSP_MAX_DEVICES 		CHIRP_MAX_NUM_SENSORS
#define CHBSP_NUM_BUSES 	    CHIRP_NUM_BUSES

#if defined(CHIRP_RTC_CAL_PULSE_LEN_MS)
	/** Length of real-time clock calibration pulse, in milliseconds :
	 * length of pulse applied to sensor INT line during clock cal
	 */
	#define CHBSP_RTC_CAL_PULSE_MS CHIRP_RTC_CAL_PULSE_LEN_MS
#else
	/* Default value */
	#define CHBSP_RTC_CAL_PULSE_MS	(100)
#endif

/* I2C Address assignments for each possible device */
#define CHIRP_I2C_ADDRS		{45, 43, 44, 42 }
#define CHIRP_I2C_BUSES		{ 0,  0,  1,  1 }

/* IRQ assignments */
#define TWI1_IRQn           FLEXCOM1_IRQn
#define TWI3_IRQn           FLEXCOM3_IRQn

/* Processor sleep mode */
#define	PROC_SLEEP_MODE		SAM_PM_SMODE_SLEEP_WFI		/* wait for interrupt */

/* Structure to track non-blocking I2C transaction data */
typedef struct {
	uint8_t		*buf_ptr;		/* pointer to data buffer */
	uint16_t	num_bytes;		/* number of bytes to transfer */
} i2c_trans_data_t;

/* TC channel used for the ultrasound timer and lsepoch of the system */
#define TC_CHANNEL_LSEPOCH     (0)
#define TC_CHANNEL_US          (1)
#define TC_CHANNEL_DELAY       (2)

/* Define the HW frequency of the TC used for the ultrasound periodic timer */
#define ULTRASOUND_TIMER_FREQUENCY (499985) /* = 32768 * 3662 / 240 */
#define DELAY_TIMER_FREQUENCY (32768 * 3662 / 32) /* EXT XC * PLLA_MUL / TIMER3_DIV = 32k * 3662 / 32 */

/* Interrupts priority (Hi > Lo) */
#define INT_PRIO_UART_COMM (0)
#define INT_PRIO_I2C_BUS (1)
#define INT_PRIO_EXT_PIN (2)
#define INT_PRIO_TIMER_US (3)
#define INT_PRIO_TIMER_EPOCH (4)

extern uint32_t chirp_pin_prog[CHBSP_MAX_DEVICES];
extern uint32_t chirp_pin_io[CHBSP_MAX_DEVICES];
extern uint32_t chirp_pin_io_irq[CHBSP_MAX_DEVICES];
extern uint32_t chirp_led_pins[];

extern ch_group_t chirp_group;

extern i2c_trans_data_t	i2c_nb_transactions[CHBSP_NUM_BUSES];		// array of structures to track non-blocking I2C transactions

extern void sensor_led_on(uint32_t pin);
extern void sensor_led_off(uint32_t pin);
extern void sensor_led_toggle(uint32_t pin);
extern void indicate_alive(void);

void switch_user_led(bool on_off);

#endif /* CHIRP_SMARTSONIC_H */
