@echo off
setlocal enabledelayedexpansion

rem Define following variable to connect on nexus server with no authentication
set PIP_TRUSTED_HOST=ussjc-swnexus01.invcorp.invensense.com
set environment=%1
set venv_jenkins_path=.venv_jenkins
set local_pip_srv_addr=https://ussjc-swnexus01.invcorp.invensense.com/repository/scm-pypi-internal-release/simple/

if "%environment%" == "" (
    @echo
    @echo Usage : call %0 ^<environment^>
    @echo environments : gcc-gnu-arm
    exit /b 0
)
goto :start_script

:print_python_version
call python -V > tmp.txt 2>nul && set /P PYTHON_VERSION=<tmp.txt && del /F tmp.txt
@echo Python version : %PYTHON_VERSION%
goto :eof

:error_build_dep_install
rem if an error happens during build dependencies installation, remove venv
rmdir /S /Q %venv_jenkins_path%
exit /b 1
goto:eof

:start_script
REM Check dependencies on build machine
REM Use python 3.10 for tests
if "%PYTHON310_HOME%" == "" (
    echo [WARNING] Variable PYTHON310_HOME not defined. Assuming python 3.10 in PATH.
) else (
    set "PATH=%PYTHON310_HOME%;%PYTHON310_HOME%\Scripts;%PATH%"
)
if "%MBS_LOCAL_REPO%" == "" (
    echo [WARNING] Variable MBS_LOCAL_REPO not defined. Assuming needed utils are on path.
)

:build_dep_install
if not exist %venv_jenkins_path% (
    @echo Installing build dependencies...
    call python -m venv %venv_jenkins_path% || goto :error_build_dep_install
    call %venv_jenkins_path%\Scripts\activate || goto :error_build_dep_install
    call :print_python_version
    call python -m pip config set --site global.extra-index-url %local_pip_srv_addr% || goto :error_build_dep_install
    call python -m pip install invn-scm-toolbox || goto :error_build_dep_install
    rem Install build dependencies from MBS:
    call mbs-pkg-install --pkg-name tool.build.ninja --pkg-version 1.10.2 || goto :error_build_dep_install
    call mbs-pkg-install --pkg-name toolchain.gcc-arm-none-eabi.official --pkg-version gcc-arm-none-eabi-9.2-2019-q4-major || goto :error_build_dep_install
)

if not "%MBS_LOCAL_REPO%" == "" (
    set "PATH=%MBS_LOCAL_REPO%\tool\build\ninja\win32\1.10.2;%PATH%"
    set "PATH=%MBS_LOCAL_REPO%\cmake\cmake-3.20.5-windows-x86_64\bin;!PATH!"
)
if "%ARM_GCC_PATH%" == "" (
    echo [WARNING] Variable ARM_GCC_PATH not defined. Assuming gcc on path.
) else (
    echo "gcc version info:"
    call %ARM_GCC_PATH%\bin\arm-none-eabi-gcc.exe --version || exit /b 1
    echo "gcc sysroot:"
    call %ARM_GCC_PATH%\bin\arm-none-eabi-gcc.exe -print-sysroot || exit /b 1
    echo "ninja version info:"
    call ninja --version || exit /b 1
    echo "cmake version info:"
    call cmake --version || exit /b 1
)

powershell -F make.ps1 -Clean || exit /b 1

if "%environment%" == "gcc-gnu-arm" (
    set platform=arm-cortex-m4
) else (
    echo Build environment "%environment%" not handled
    exit /b 1
)
powershell -F make.ps1 -Generator "Ninja" -Platform !platform! || exit /b 1
